#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xml-conduit
version:              1.9.1.1
visibility:           public
id:                   xml-conduit-1.9.1.1-5pCpotf51DzBhLZtCry6QK
key:                  xml-conduit-1.9.1.1-5pCpotf51DzBhLZtCry6QK
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>

stability:            Stable
homepage:             http://github.com/snoyberg/xml
synopsis:
    Pure-Haskell utilities for dealing with XML with the conduit package.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.

category:             XML, Conduit
abi:                  96d69a5d3c12f7d3547d606b247720eb
exposed:              True
exposed-modules:
    Text.XML Text.XML.Cursor Text.XML.Cursor.Generic
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved

hidden-modules:       Text.XML.Stream.Token
import-dirs:          /usr/lib/ghc-8.10.5/site-local/xml-conduit-1.9.1.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/xml-conduit-1.9.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/xml-conduit-1.9.1.1
hs-libraries:         HSxml-conduit-1.9.1.1-5pCpotf51DzBhLZtCry6QK
depends:
    attoparsec-0.14.1-CDW2c9fsk3y4jVQKNBcpib base-4.14.2.0
    blaze-html-0.9.1.2-3gWJOEFN3Rn7Mv2jAJdKwl
    blaze-markup-0.8.2.8-8RebaU3zReM4AoTFuL4PYs bytestring-0.10.12.0
    conduit-1.3.4.1-GHgRKpknFuqDscwzVojbiE
    conduit-extra-1.3.5-6wbdzvOjyuAGkpGhMnpbur containers-0.6.4.1
    data-default-class-0.1.2.0-9cFfQKP7sucLLfD3ZZyiPI deepseq-1.4.4.0
    resourcet-1.2.4.2-7etOfd8fePh2l91avxjTIe text-1.2.4.1
    transformers-0.5.6.2 xml-types-0.3.8-Gz3On8Uo3JN2rSYUSThjSo

haddock-interfaces:   /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html:         /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

